PathwayProjections
==================

.. _PathwayProjection_Subtypes:

.. toctree::
   :maxdepth: 1

.. container:: subclasses

       *Subclasses*
       MappingProjection
       MaskedMappingProjection
       AutoAssociativeProjection
